tiled.client.xarray.VariableClient
==================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: VariableClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VariableClient.__init__
      ~VariableClient.download
      ~VariableClient.export
      ~VariableClient.new_variation
      ~VariableClient.read
      ~VariableClient.read_block
      ~VariableClient.refresh
      ~VariableClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VariableClient.context
      ~VariableClient.data
      ~VariableClient.formats
      ~VariableClient.item
      ~VariableClient.metadata
      ~VariableClient.offline
      ~VariableClient.path
      ~VariableClient.uri
      ~VariableClient.username
   
   